# encoding: utf-8
from . import *


def tableCaption(
        content=""):
    """
    *Generate a table caption - TBS style*

    **Key Arguments:**
        - ``content`` -- the content

    **Return:**
        - ``tableCaption`` -- the table caption
    """
    tableCaption = """<caption class="">%(content)s</caption>""" % locals()

    return tableCaption



# encoding: utf-8
from . import *


def _container(
    responsive=True,
    content='',
    htmlId=False,
    htmlClass=False,
    onPhone=True,
    onTablet=True,
    onDesktop=True,
):
    """ *The over-all content container for the twitter bootstrap webpage*

    **Key Arguments:**
        - ``responsive`` -- fluid layout if true, fixed if false
        - ``content`` -- html content of the container div
        - ``htmlId`` -- the id of the container
        - ``htmlClass`` -- the class of the container
        - ``onPhone`` -- does this container get displayed on a phone sized screen
        - ``onTablet`` -- does this container get displayed on a tablet sized screen
        - ``onDesktop`` -- does this container get displayed on a desktop sized screen

    **Return:**
        - ``container`` 
    """

    if responsive:
        responsive = '-fluid'
    else:
        responsive = ''
    if htmlId:
        htmlId = """id="%(htmlId)s" """ % locals()
    else:
        htmlId = ''
    if not htmlClass:
        htmlClass = ''
    if onPhone:
        onPhone = ''
    else:
        onPhone = 'hidden-phone'
    if onTablet:
        onTablet = ''
    else:
        onTablet = 'hidden-tablet'
    if onDesktop:
        onDesktop = ''
    else:
        onDesktop = 'hidden-desktop'
    container = """
        <div class="container%(responsive)s %(htmlClass)s %(onPhone)s %(onTablet)s %(onDesktop)s" %(htmlId)s>
            %(content)s
        </div>
    """ % locals()
    return container



# encoding: utf-8
from . import *


def abbr(
        abbreviation="",
        fullWord=""):
    """
    *Get HTML5 Abbreviation*

    **Key Arguments:**
        - ``abbreviation`` -- the abbreviation
        - ``fullWord`` -- the full word

    **Return:**
        - abbr
    """

    abbr = """<abbr title="%(fullWord)s" class="initialism">%(abbreviation)s</abbr>""" % locals(
    )

    return abbr



# encoding: utf-8
from . import *


def label(text='', level='default'):
    """ *Generate a label - TBS style*

    **Key Arguments:**
        - ``text`` -- the text content
        - ``level`` -- the level colour of the label [ "default" | "success" | "warning" | "important" | "info" | "inverse" ]

    **Return:**
        - ``label`` -- the label """

    if level == 'default':
        level = ''
    else:
        level = 'label-%(level)s' % locals()
    label = """
        <span class="label %(level)s" id="  ">
            %(text)s
        </span>""" % locals()
    return label



from _container import _container
from htmlDocument import htmlDocument
from head import head

from grid_row import grid_row
from grid_column import grid_column
from row_adjustable import row_adjustable

from body import body

from login_page import login_page



from responsive_navigation_bar import responsive_navigation_bar
from nav_list import nav_list
from searchbox import searchbox
from tabbableNavigation import tabbableNavigation
from navBar import navBar
from pagination import pagination
from is_navStyle_active import is_navStyle_active


# CREATED : 20130508


def closeIcon():
    """ *Get close icon. The generic close icon for dismissing content like modals and alerts.*

    **Key Arguments:**

    **Return:**
        - ``closeIcon`` -- the closeIcon """

    closeIcon = """<button class="close">&times;</button>"""
    return closeIcon



# encoding: utf-8
from . import *


def unescape_html(html):
    """
    *Unescape a string previously escaped with cgi.escape()*

    **Key Arguments:**
        - ``dbConn`` -- mysql database connection
        - ``log`` -- logger
        - ``html`` -- the string to be unescaped

    **Return:**
        - ``html`` -- the unescaped string
    """
    html = html.replace("&lt;", "<")
    html = html.replace("&gt;", ">")
    html = html.replace("&quot;", '"')
    # THIS HAS TO BE LAST:
    html = html.replace("&amp;", "&")

    return html



# encoding: utf-8
from . import *


def pageHeader(
        headline="",
        tagline=""):
    """
    *Generate a pageHeader - TBS style*

    **Key Arguments:**
        - ``headline`` -- the headline text
        - ``tagline`` -- the tagline text for below the headline

    **Return:**
        - ``pageHeader`` -- the pageHeader
    """
    pageHeader = """
        <div class="page-header" id="  ">
            <h1>%(headline)s<br><small>%(tagline)s</small></h1>
        </div>""" % locals()

    return pageHeader



from helpers import *
from plots import *
from tables import *
from urls import *
from modals import *
from addons import *
from scaffolding import *
from helpers import *
from buttons import *
from code import *
from dropdowns import *
from forms import *
from labelsAndBadges import *
from navigation import *
from typography import *
from images import *




import os
from nose import with_setup

## SETUP AND TEARDOWN FIXTURE FUNCTIONS FOR THE ENTIRE MODULE
def setUpModule():
    "set up test fixtures"
    moduleDirectory = os.path.dirname(__file__)

    # SETUP PATHS TO COMMONG DIRECTORIES FOR TEST DATA
    global pathToInputDataDir, pathToOutputDir, pathToOutputDataDir
    pathToInputDataDir = moduleDirectory+"/input/data/"
    pathToOutputDir = moduleDirectory+"/output/"
    pathToOutputDataDir = pathToOutputDir+"data/"

    # SETUP THE TEST LOG FILE
    global testlog
    testlog = open(pathToOutputDir + "tests.log", 'w')

    return None

def tearDownModule():
    "tear down test fixtures"
    # CLOSE THE TEST LOG FILE
    testlog.close()
    return None


## SETUP AND TEARDOWN FIXTURE FUNCTIONS
def setUpFunc():
    "set up the test fixtures"

    return None

def tearDownFunc():
    "tear down the test fixtures"

    return None




from p import p
from emphasizeText import emphasizeText
from abbr import abbr
from address import address
from blockquote import blockquote
from ul import ul
from li import li
from a import a
from ol import ol
from descriptionLists import descriptionLists
from heroUnit import heroUnit
from pageHeader import pageHeader
from coloredText import coloredText